@@ -56,7 +56,8 @@ class FileJob(Job):
         return 'file'
 
     def execute(self):
-        self.read_flo = open(self.definition.get('file'), 'rb')
+        if os.path.exists(self.definition.get('file')):
+            self.read_flo = open(self.definition.get('file'), 'rb')
 
 
 class DirectoryJob(Job):
@@ -75,6 +76,9 @@ class DirectoryJob(Job):
         if not path:
             path = self.definition.get('directory')
 
+        if not os.path.exists(path):
+            return
+
         for ent in os.listdir(path):
             p = os.path.join(path, ent)
             if os.path.isdir(p):
